@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook.
 
-  Copyright (c) 2009-2018 Laurent Montel <montel@kde.org>
+  Copyright (c) 2009-2019 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ KAddressBookPart::KAddressBookPart(QWidget *parentWidget, QObject *parent, const
     initAction();
 
     topLayout->addWidget(mMainWidget);
-    topLayout->setMargin(0);
+    topLayout->setContentsMargins(0, 0, 0, 0);
     setXMLFile(QStringLiteral("kaddressbookui.rc"));
 }
 
